@@ -9,7 +9,6 @@ from typing import (
     Callable,
     Coroutine,
     Optional,
-    TypeVar,
     Union,
     cast,
 )
@@ -24,14 +23,12 @@ from pydoll.exceptions import (
     CommandExecutionTimeout,
     WebSocketConnectionClosed,
 )
-from pydoll.protocol.base import Command, Event, Response
+from pydoll.protocol.base import CDPEvent, Command, Response, T_CommandParams, T_CommandResponse
 from pydoll.utils import get_browser_ws_address
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
-T = TypeVar('T')
-
 
 class ConnectionHandler:
     """
@@ -43,10 +40,11 @@ class ConnectionHandler:
 
     def __init__(
         self,
-        connection_port: int,
+        connection_port: Optional[int] = None,
         page_id: Optional[str] = None,
         ws_address_resolver: Callable[[int], Coroutine[Any, Any, str]] = get_browser_ws_address,
         ws_connector: type[Connect] = websockets.connect,
+        ws_address: Optional[str] = None,
     ):
         """
         Initialize connection handler.
@@ -56,11 +54,13 @@ class ConnectionHandler:
             page_id: Target page ID. If None, connects to browser-level endpoint.
             ws_address_resolver: Function to resolve WebSocket URL from port.
             ws_connector: WebSocket connection factory (mainly for testing).
+            ws_address: WebSocket address. It has priority over connection_port and page_id.
         """
         self._connection_port = connection_port
         self._page_id = page_id
         self._ws_address_resolver = ws_address_resolver
         self._ws_connector = ws_connector
+        self._ws_address = ws_address
         self._ws_connection: Optional[ClientConnection] = None
         self._command_manager = CommandsManager()
         self._events_handler = EventsManager()
@@ -85,7 +85,9 @@ class ConnectionHandler:
             return True
         return False
 
-    async def execute_command(self, command: Command[T], timeout: int = 10) -> T:
+    async def execute_command(
+        self, command: Command[T_CommandParams, T_CommandResponse], timeout: int = 10
+    ) -> T_CommandResponse:
         """
         Send CDP command and await response.
 
@@ -174,9 +176,11 @@ class ConnectionHandler:
 
     async def _resolve_ws_address(self):
         """Determine correct WebSocket address based on page ID."""
+        if self._ws_address:
+            return self._ws_address
         if not self._page_id:
             return await self._ws_address_resolver(self._connection_port)
-        return f'ws://localhost:{self._connection_port}/devtools/page/{self._page_id}'
+        return f'ws://localhost:{self._connection_port}/devtools/page/{self._page_id}'  # noqa: E501
 
     async def _handle_connection_loss(self):
         """Clean up resources after connection loss."""
@@ -217,11 +221,11 @@ class ConnectionHandler:
             message = cast(Response, message)
             await self._handle_command_message(message)
         else:
-            message = cast(Event, message)
+            message = cast(CDPEvent, message)
             await self._handle_event_message(message)
 
     @staticmethod
-    def _parse_message(raw_message: str) -> Union[Event, Response, None]:
+    def _parse_message(raw_message: str) -> Union[CDPEvent, Response, None]:
         """Parse raw message string into JSON object."""
         try:
             return json.loads(raw_message)
@@ -230,7 +234,7 @@ class ConnectionHandler:
             return None
 
     @staticmethod
-    def _is_command_response(message: Union[Event, Response]) -> bool:
+    def _is_command_response(message: Union[CDPEvent, Response]) -> bool:
         """Determine if message is command response or event notification."""
         return 'id' in message and isinstance(message.get('id'), int)
 
@@ -239,7 +243,7 @@ class ConnectionHandler:
         logger.debug(f'Processing command response: {message.get("id")}')
         self._command_manager.resolve_command(message['id'], json.dumps(message))
 
-    async def _handle_event_message(self, message: Event):
+    async def _handle_event_message(self, message: CDPEvent):
         """Process event notification messages."""
         event_type = message.get('method', 'unknown-event')
         logger.debug(f'Processing {event_type} event')
